module Sitepass

  class Command

    class << self

      def exec(arguments)
        first, *rest = arguments

        case first && first.to_sym
        when nil then
          help
        when :help then
          help
        when :generate then
          generate
        when :config then
          config
        when :key then
          key
        when :delete then
          delete
        else
          generate_password(arguments)
        end
      end

      def help
puts %Q(
usage: sitepass <domain> [<seed>]

  domain is a string to generate a password for
    ex. "example.com"

  seed is a salt or seed
    ex. #{Time.now.year}

The other commands are:
  help      this command
  generate  generate a key in #{Config.filename}
  key       dump the key
  delete    delete the file at #{Config.filename}
).strip
      end

      def generate
        if Key.exists?
          puts "Key already exists at #{Config.filename}"
        else
          Key.generate
          puts "Key generated at #{Config.filename}"
        end
      end

      def generate_password(arguments)
        if Key.exists?
          password = Password.new(*arguments)
          pass = password.phrase.join(' ')
          `printf "#{pass.strip}" | pbcopy`
          puts "Password copied to clipboard"
        else
          puts "Key does not exist - run sitepass generate"
        end
      end

      def key
        puts `cat #{Config.filename}`
      end

      def delete
        `rm #{Config.filename}`
        puts "Config file at #{Config.filename} was deleted"
      end

    end

  end

end