module Sitepass

  class Password

    attr_reader :seed

    def initialize(site, seed = nil)
      raise "No key" unless Key.exists?

      @host = site
      @seed = seed || self.class.seed
    end

    def self.seed
      if !Config.load["seed"]
        Config.load["seed"] = 1
      end
      Config.load["seed"]
    end

    def self.number_of_words
      Config.load["number_of_words"] || 4
    end

    def host
      OpenSSL::PKCS5.pbkdf2_hmac_sha1(@host, Key.load, 10_000, 512)
    end

    def sha1
      @sha1 ||= begin
        presha = "sitepass-#{Key.load}#{self.host}#{seed}"
        Digest::SHA1.hexdigest presha
      end
    end

    def phrase
      (0...self.class.number_of_words).map do |i|
        sub = sha1.split('')[i * 3, 3].join
        Word.list[sub.to_i(16)]
      end
    end

  end

end